@@ -1,12 +1,9 @@
       SUBROUTINE PCGBTRF( N, BWL, BWU, A, JA, DESCA, IPIV, AF, LAF,
      $                    WORK, LWORK, INFO )
 *
-*
-*
-*  -- ScaLAPACK routine (version 1.7) --
-*     University of Tennessee, Knoxville, Oak Ridge National Laboratory,
-*     and University of California, Berkeley.
-*     November 15, 1997
+*  -- ScaLAPACK routine (version 2.0.2) --
+*     Univ. of Tennessee, Univ. of California Berkeley, Univ. of Colorado Denver
+*     May 1 2012
 *
 *     .. Scalar Arguments ..
       INTEGER            BWL, BWU, INFO, JA, LAF, LWORK, N
@@ -389,7 +386,7 @@
 *     ..
 *     .. External Subroutines ..
       EXTERNAL           BLACS_GRIDEXIT, BLACS_GRIDINFO, CAXPY, CGEMM,
-     $                   CGERV2D, CGESD2D, CLACPY, CLATCPY, CPBTRF,
+     $                   CGERV2D, CGESD2D, CLAMOV, CLATCPY, CPBTRF,
      $                   CPOTRF, CSYRK, CTBTRS, CTRMM, CTRRV2D, CTRSD2D,
      $                   CTRSM, CTRTRS, DESC_CONVERT, GLOBCHK, PXERBLA,
      $                   RESHAPE
@@ -841,7 +838,7 @@
 *     DBPTR = Pointer to diagonal blocks in A
       DBPTR = BW+1 + LBWU + LN*LLDA
 *
-      CALL CLACPY('G',BM,BN, A(DBPTR),LLDA-1,
+      CALL CLAMOV('G',BM,BN, A(DBPTR),LLDA-1,
      $     AF(BBPTR + BW*LDBB),LDBB)
 *
 *     Zero out any junk entries that were copied
@@ -857,7 +854,7 @@
 *        ODPTR = Pointer to offdiagonal blocks in A
 *
          ODPTR = LM-BM+1
-         CALL CLACPY('G',BM,BW, AF(ODPTR),LM,
+         CALL CLAMOV('G',BM,BW, AF(ODPTR),LM,
      $        AF(BBPTR +2*BW*LDBB),LDBB)
       ENDIF
 *
@@ -924,7 +921,7 @@
 *
 *                     Copy diagonal block to align whole system
 *
-                      CALL CLACPY( 'G', BMN, BW, AF( BBPTR+BM ),
+                      CALL CLAMOV( 'G', BMN, BW, AF( BBPTR+BM ),
      $                  LDBB, AF( BBPTR+2*BW*LDBB+BM ), LDBB )
                    ENDIF
 *
@@ -950,7 +947,7 @@
                 CALL CGESD2D( ICTXT, BM, 2*BW, AF(BBPTR+BW*LDBB),
      $               LDBB, 0, NEICOL )
 *
-                CALL CLACPY('G',BM, 2*BW, AF(BBPTR+BW*LDBB),LDBB,
+                CALL CLAMOV('G',BM, 2*BW, AF(BBPTR+BW*LDBB),LDBB,
      $               AF(BBPTR+BMN),LDBB)
 *
                 DO 31 J=BBPTR+2*BW*LDBB, BBPTR+3*BW*LDBB-1, LDBB
@@ -966,7 +963,7 @@
 *
 *                  Copy diagonal block to align whole system
 *
-                   CALL CLACPY( 'G', BM, BW, AF( BBPTR+BMN ),
+                   CALL CLAMOV( 'G', BM, BW, AF( BBPTR+BMN ),
      $               LDBB, AF( BBPTR+2*BW*LDBB+BMN ), LDBB )
                 ENDIF
 *
@@ -1029,10 +1026,10 @@
 *                  Local copying in the block bidiagonal area
 *
 *
-                   CALL CLACPY('G',BM,BW,
+                   CALL CLAMOV('G',BM,BW,
      $                  AF(BBPTR+BW),
      $                  LDBB, AF(BBPTR+BW*LDBB), LDBB)
-                   CALL CLACPY('G',BM,BW,
+                   CALL CLAMOV('G',BM,BW,
      $                  AF(BBPTR+2*BW*LDBB+BW),
      $                  LDBB, AF(BBPTR+2*BW*LDBB), LDBB)
 *
