@@ -1,10 +1,10 @@
       SUBROUTINE PCGEQPF( M, N, A, IA, JA, DESCA, IPIV, TAU, WORK,
      $                    LWORK, RWORK, LRWORK, INFO )
 *
-*  -- ScaLAPACK routine (version 1.5) --
+*  -- ScaLAPACK routine (version 1.7) --
 *     University of Tennessee, Knoxville, Oak Ridge National Laboratory,
 *     and University of California, Berkeley.
-*     May 1, 1997
+*     March 14, 2000
 *
 *     .. Scalar Arguments ..
       INTEGER            IA, JA, INFO, LRWORK, LWORK, M, N
@@ -481,15 +481,19 @@
      $      JJ = JJ + 1
          IF( MOD( J, DESCA( NB_ ) ).EQ.0 )
      $      ICURCOL = MOD( ICURCOL+1, NPCOL )
-         IF( MYROW.EQ.ICURROW ) THEN
-            CALL CGEBS2D( ICTXT, 'Columnwise', ' ', 1, JJA+NQ-JJ,
-     $                    A( II+( MIN( JJA+NQ-1, JJ )-1 )*LDA ), LDA )
-            CALL CCOPY( JJA+NQ-JJ, A( II+( MIN( JJA+NQ-1, JJ )-1)*LDA ),
-     $                  LDA, WORK( MIN( JJA+NQ-1, JJ ) ), 1 )
-         ELSE
-            CALL CGEBR2D( ICTXT, 'Columnwise', ' ', JJA+NQ-JJ, 1,
-     $                    WORK( MIN( JJA+NQ-1, JJ ) ), MAX( 1, NQ ),
-     $                    ICURROW, MYCOL )
+         IF( (JJA+NQ-JJ).GT.0 ) THEN
+            IF( MYROW.EQ.ICURROW ) THEN
+               CALL CGEBS2D( ICTXT, 'Columnwise', ' ', 1, JJA+NQ-JJ,
+     $                       A( II+( MIN( JJA+NQ-1, JJ )-1 )*LDA ),
+     $                       LDA )
+               CALL CCOPY( JJA+NQ-JJ, A( II+( MIN( JJA+NQ-1, JJ )
+     $                     -1)*LDA ), LDA, WORK( MIN( JJA+NQ-1, JJ ) ),
+     $                     1 )
+            ELSE
+               CALL CGEBR2D( ICTXT, 'Columnwise', ' ', JJA+NQ-JJ, 1,
+     $                       WORK( MIN( JJA+NQ-1, JJ ) ), MAX( 1, NQ ),
+     $                       ICURROW, MYCOL )
+            END IF
          END IF
 *
          JN = MIN( ICEIL( J+1, DESCA( NB_ ) ) * DESCA( NB_ ),
