@@ -1,10 +1,9 @@
       SUBROUTINE PDDBTRSV( UPLO, TRANS, N, BWL, BWU, NRHS, A, JA, DESCA,
      $                     B, IB, DESCB, AF, LAF, WORK, LWORK, INFO )
 *
-*  -- ScaLAPACK routine (version 1.7) --
-*     University of Tennessee, Knoxville, Oak Ridge National Laboratory,
-*     and University of California, Berkeley.
-*     April 3, 2000
+*  -- ScaLAPACK routine (version 2.0.2) --
+*     Univ. of Tennessee, Univ. of California Berkeley, Univ. of Colorado Denver
+*     May 1 2012
 *
 *     .. Scalar Arguments ..
       CHARACTER          TRANS, UPLO
@@ -399,7 +398,7 @@
 *     ..
 *     .. External Subroutines ..
       EXTERNAL           BLACS_GRIDEXIT, BLACS_GRIDINFO, DESC_CONVERT,
-     $                   DGEMM, DGERV2D, DGESD2D, DLACPY, DMATADD,
+     $                   DGEMM, DGERV2D, DGESD2D, DLAMOV, DMATADD,
      $                   DTBTRS, DTRMM, GLOBCHK, PXERBLA, RESHAPE
 *     ..
 *     .. External Functions ..
@@ -777,7 +776,7 @@
 *           First copy and multiply it into temporary storage,
 *             then use it on RHS
 *
-               CALL DLACPY( 'N', BWL, NRHS,
+               CALL DLAMOV( 'N', BWL, NRHS,
      $                      B( PART_OFFSET+ODD_SIZE-BWL+1 ), LLDB,
      $                      WORK( 1 ), MAX_BW )
 *
@@ -1111,7 +1110,7 @@
 *         First copy and multiply it into temporary storage,
 *           then use it on RHS
 *
-               CALL DLACPY( 'N', BWL, NRHS, B( PART_OFFSET+ODD_SIZE+1 ),
+               CALL DLAMOV( 'N', BWL, NRHS, B( PART_OFFSET+ODD_SIZE+1 ),
      $                      LLDB, WORK( 1+MAX_BW-BWL ), MAX_BW )
 *
                CALL DTRMM( 'L', 'U', 'T', 'N', BWL, NRHS, -ONE,
@@ -1163,7 +1162,7 @@
 *           First copy and multiply it into temporary storage,
 *             then use it on RHS
 *
-               CALL DLACPY( 'N', BWU, NRHS,
+               CALL DLAMOV( 'N', BWU, NRHS,
      $                      B( PART_OFFSET+ODD_SIZE-BWU+1 ), LLDB,
      $                      WORK( 1 ), MAX_BW )
 *
@@ -1497,7 +1496,7 @@
 *         First copy and multiply it into temporary storage,
 *           then use it on RHS
 *
-               CALL DLACPY( 'N', BWU, NRHS, B( PART_OFFSET+ODD_SIZE+1 ),
+               CALL DLAMOV( 'N', BWU, NRHS, B( PART_OFFSET+ODD_SIZE+1 ),
      $                      LLDB, WORK( 1+MAX_BW-BWU ), MAX_BW+BWL )
 *
                CALL DTRMM( 'L', 'L', 'N', 'N', BWU, NRHS, -ONE,
