@@ -349,7 +349,7 @@ void pzrot_( n, X, ix, jx, desc_X, incx, Y, iy, jy, desc_Y, incy, c, s )
                       &X[iix-1+(jjx-1)*desc_X[LLD_]], &desc_X[LLD_],
                       &iyrow, &mycol );
             buff = (complex16 *)getpbbuf( "PZROT", nq*sizeof(complex16) );
-            zgerv2d_( &ictxt, &nq, &ione, buff, &ione, &iyrow, &mycol );
+            zgerv2d_( &ictxt, &nq, &ione, buff, &nq, &iyrow, &mycol );
             zrot_( &nq, &X[iix-1+(jjx-1)*desc_X[LLD_]], &desc_X[LLD_],
                         buff, &ione, c, s );
          }
@@ -359,7 +359,7 @@ void pzrot_( n, X, ix, jx, desc_X, incx, Y, iy, jy, desc_Y, incy, c, s )
                       &Y[iiy-1+(jjy-1)*desc_Y[LLD_]], &desc_Y[LLD_],
                       &ixrow, &mycol );
             buff = (complex16 *)getpbbuf( "PZROT", nq*sizeof(complex16) );
-            zgerv2d_( &ictxt, &nq, &ione, buff, &ione, &ixrow, &mycol );
+            zgerv2d_( &ictxt, &nq, &ione, buff, &nq, &ixrow, &mycol );
             zrot_( &nq, buff, &ione,
                         &Y[iiy-1+(jjy-1)*desc_Y[LLD_]], &desc_Y[LLD_], c, s );
          }
@@ -389,7 +389,7 @@ void pzrot_( n, X, ix, jx, desc_X, incx, Y, iy, jy, desc_Y, incy, c, s )
                       &X[iix-1+(jjx-1)*desc_X[LLD_]], &desc_X[LLD_],
                       &myrow, &iycol );
             buff = (complex16 *)getpbbuf( "PZROT", np*sizeof(complex16) );
-            zgerv2d_( &ictxt, &np, &ione, buff, &ione, &myrow, &iycol );
+            zgerv2d_( &ictxt, &np, &ione, buff, &np, &myrow, &iycol );
             zrot_( &np, &X[iix-1+(jjx-1)*desc_X[LLD_]], incx,
                         buff, &ione, c, s );
          }
@@ -399,7 +399,7 @@ void pzrot_( n, X, ix, jx, desc_X, incx, Y, iy, jy, desc_Y, incy, c, s )
                       &Y[iiy-1+(jjy-1)*desc_Y[LLD_]], &desc_Y[LLD_],
                       &myrow, &ixcol );
             buff = (complex16 *)getpbbuf( "PZROT", np*sizeof(complex16) );
-            zgerv2d_( &ictxt, &np, &ione, buff, &ione, &myrow, &ixcol );
+            zgerv2d_( &ictxt, &np, &ione, buff, &np, &myrow, &ixcol );
             zrot_( &np, buff, &ione,
                         &Y[iiy-1+(jjy-1)*desc_Y[LLD_]], incy, c, s );
          }
