@@ -1,9 +1,9 @@
       PROGRAM PCTRDDRIVER
 *
-*  -- ScaLAPACK testing driver (version 1.5) --
+*  -- ScaLAPACK testing driver (version 1.7) --
 *     University of Tennessee, Knoxville, Oak Ridge National Laboratory,
 *     and University of California, Berkeley.
-*     May 1, 1997
+*     October 15, 1999
 *
 *  Purpose
 *  ========
@@ -63,17 +63,17 @@
       PARAMETER          ( BLOCK_CYCLIC_2D = 1, DLEN_ = 9, DTYPE_ = 1,
      $                     CTXT_ = 2, M_ = 3, N_ = 4, MB_ = 5, NB_ = 6,
      $                     RSRC_ = 7, CSRC_ = 8, LLD_ = 9 )
-      INTEGER            CPLXSZ, MEMSIZ, NTESTS, REALSZ, TOTMEM
+      INTEGER            CPLXSZ, REALSZ, TOTMEM, MEMSIZ, NTESTS
       COMPLEX            PADVAL
       PARAMETER          ( CPLXSZ = 8, REALSZ = 4, TOTMEM = 2000000,
-     $                     MEMSIZ = TOTMEM / CPLXSZ, NTESTS = 20,
-     $                     PADVAL = ( -9923.0E+0, -9923.0E+0 ) )
+     $                   MEMSIZ = TOTMEM / CPLXSZ, NTESTS = 20,
+     $                   PADVAL = ( -9923.0E+0, -9923.0E+0 ) )
 *     ..
 *     .. Local Scalars ..
+      LOGICAL            CHECK
       CHARACTER          UPLO
       CHARACTER*6        PASSED
       CHARACTER*80       OUTFILE
-      LOGICAL            CHECK
       INTEGER            I, IAM, IASEED, ICTXT, IMIDPAD, INFO, IPA, IPD,
      $                   IPE, IPOSTPAD, IPREPAD, IPT, IPW, ITEMP, J, K,
      $                   KFAIL, KPASS, KSKIP, KTESTS, LCM, LWORK, MYCOL,
@@ -85,24 +85,23 @@
 *     ..
 *     .. Local Arrays ..
       INTEGER            DESCA( DLEN_ ), IERR( 1 ), NBVAL( NTESTS ),
-     $                   NVAL( NTESTS ), PVAL( NTESTS ),
-     $                   QVAL( NTESTS )
-      DOUBLE PRECISION   CTIME( 1 ), WTIME( 1 )
+     $                   NVAL( NTESTS ), PVAL( NTESTS ), QVAL( NTESTS )
       COMPLEX            MEM( MEMSIZ )
+      DOUBLE PRECISION   CTIME( 1 ), WTIME( 1 )
 *     ..
 *     .. External Subroutines ..
       EXTERNAL           BLACS_BARRIER, BLACS_EXIT, BLACS_GET,
      $                   BLACS_GRIDEXIT, BLACS_GRIDINFO, BLACS_GRIDINIT,
      $                   BLACS_PINFO, DESCINIT, IGSUM2D, PCCHEKPAD,
-     $                   PCFILLPAD, PCLAFCHK, PCMATGEN,
-     $                   PCHETDRV, PCHETRD, PCTRDINFO,
-     $                   SLBOOT, SLCOMBINE, SLTIMER
+     $                   PCFILLPAD, PCHETDRV, PCHETRD, PCLAFCHK,
+     $                   PCMATGEN, PCTRDINFO, PCTTRDTESTER, SLBOOT,
+     $                   SLCOMBINE, SLTIMER
 *     ..
 *     .. External Functions ..
       LOGICAL            LSAME
       INTEGER            ICEIL, ILCM, NUMROC
       REAL               PCLANHE
-      EXTERNAL           ICEIL, ILCM, LSAME, NUMROC, PCLANHE
+      EXTERNAL           LSAME, ICEIL, ILCM, NUMROC, PCLANHE
 *     ..
 *     .. Intrinsic Functions ..
       INTRINSIC          DBLE, MAX
@@ -112,6 +111,8 @@
 *     ..
 *     .. Executable Statements ..
 *
+      IF( BLOCK_CYCLIC_2D*CSRC_*CTXT_*DLEN_*DTYPE_*LLD_*MB_*M_*NB_*N_*
+     $    RSRC_.LT.0 )STOP
 *     Get starting information
 *
       CALL BLACS_PINFO( IAM, NPROCS )
@@ -142,21 +143,21 @@
          IERR( 1 ) = 0
          IF( NPROW.LT.1 ) THEN
             IF( IAM.EQ.0 )
-     $         WRITE( NOUT, FMT = 9999 ) 'GRID', 'nprow', NPROW
+     $         WRITE( NOUT, FMT = 9999 )'GRID', 'nprow', NPROW
             IERR( 1 ) = 1
          ELSE IF( NPCOL.LT.1 ) THEN
             IF( IAM.EQ.0 )
-     $         WRITE( NOUT, FMT = 9999 ) 'GRID', 'npcol', NPCOL
+     $         WRITE( NOUT, FMT = 9999 )'GRID', 'npcol', NPCOL
             IERR( 1 ) = 1
          ELSE IF( NPROW*NPCOL.GT.NPROCS ) THEN
             IF( IAM.EQ.0 )
-     $         WRITE( NOUT, FMT = 9998 ) NPROW*NPCOL, NPROCS
+     $         WRITE( NOUT, FMT = 9998 )NPROW*NPCOL, NPROCS
             IERR( 1 ) = 1
          END IF
 *
          IF( IERR( 1 ).GT.0 ) THEN
             IF( IAM.EQ.0 )
-     $         WRITE( NOUT, FMT = 9997 ) 'grid'
+     $         WRITE( NOUT, FMT = 9997 )'grid'
             KSKIP = KSKIP + 1
             GO TO 30
          END IF
@@ -170,7 +171,7 @@
 *        Go to bottom of loop if this case doesn't use my process
 *
          IF( MYROW.GE.NPROW .OR. MYCOL.GE.NPCOL )
-     $      GOTO 30
+     $      GO TO 30
 *
          DO 20 J = 1, NMAT
 *
@@ -181,7 +182,7 @@
             IERR( 1 ) = 0
             IF( N.LT.1 ) THEN
                IF( IAM.EQ.0 )
-     $            WRITE( NOUT, FMT = 9999 ) 'MATRIX', 'N', N
+     $            WRITE( NOUT, FMT = 9999 )'MATRIX', 'N', N
                IERR( 1 ) = 1
             END IF
 *
@@ -191,7 +192,7 @@
 *
             IF( IERR( 1 ).GT.0 ) THEN
                IF( IAM.EQ.0 )
-     $            WRITE( NOUT, FMT = 9997 ) 'matrix'
+     $            WRITE( NOUT, FMT = 9997 )'matrix'
                KSKIP = KSKIP + 1
                GO TO 20
             END IF
@@ -200,7 +201,7 @@
 *
             DO 10 K = 1, NNB
 *
-               NB  = NBVAL( K )
+               NB = NBVAL( K )
 *
 *              Make sure nb is legal
 *
@@ -208,7 +209,7 @@
                IF( NB.LT.1 ) THEN
                   IERR( 1 ) = 1
                   IF( IAM.EQ.0 )
-     $               WRITE( NOUT, FMT = 9999 ) 'NB', 'NB', NB
+     $               WRITE( NOUT, FMT = 9999 )'NB', 'NB', NB
                END IF
 *
 *              Check all processes for an error
@@ -217,7 +218,7 @@
 *
                IF( IERR( 1 ).GT.0 ) THEN
                   IF( IAM.EQ.0 )
-     $               WRITE( NOUT, FMT = 9997 ) 'NB'
+     $               WRITE( NOUT, FMT = 9997 )'NB'
                   KSKIP = KSKIP + 1
                   GO TO 10
                END IF
@@ -227,12 +228,12 @@
                NP = NUMROC( N, NB, MYROW, 0, NPROW )
                NQ = NUMROC( N, NB, MYCOL, 0, NPCOL )
                IF( CHECK ) THEN
-                  IPREPAD  = MAX( NB, NP )
-                  IMIDPAD  = NB
+                  IPREPAD = MAX( NB, NP )
+                  IMIDPAD = NB
                   IPOSTPAD = MAX( NB, NQ )
                ELSE
-                  IPREPAD  = 0
-                  IMIDPAD  = 0
+                  IPREPAD = 0
+                  IMIDPAD = 0
                   IPOSTPAD = 0
                END IF
 *
@@ -247,7 +248,7 @@
 *
                IF( IERR( 1 ).LT.0 ) THEN
                   IF( IAM.EQ.0 )
-     $               WRITE( NOUT, FMT = 9997 ) 'descriptor'
+     $               WRITE( NOUT, FMT = 9997 )'descriptor'
                   KSKIP = KSKIP + 1
                   GO TO 10
                END IF
@@ -283,11 +284,11 @@
                   ITEMP = 2*NQ + NP
                   IF( NPROW.NE.NPCOL ) THEN
                      LCM = ILCM( NPROW, NPCOL )
-                     ITEMP = NB*ICEIL( ICEIL( NP, NB ), LCM/NPROW ) +
+                     ITEMP = NB*ICEIL( ICEIL( NP, NB ), LCM / NPROW ) +
      $                       ITEMP
                   END IF
                   ITEMP = MAX( ICEIL( REALSZ*ITEMP, CPLXSZ ),
-     $                         2*(NB+NP)*NB )
+     $                    2*( NB+NP )*NB )
                   WORKSIZ = MAX( LWORK, ITEMP ) + IPOSTPAD
                END IF
 *
@@ -296,8 +297,8 @@
                IERR( 1 ) = 0
                IF( IPW+WORKSIZ.GT.MEMSIZ ) THEN
                   IF( IAM.EQ.0 )
-     $               WRITE( NOUT, FMT = 9996 ) 'Tridiagonal reduction',
-     $                      ( IPW+WORKSIZ )*CPLXSZ
+     $               WRITE( NOUT, FMT = 9996 )'Tridiagonal reduction',
+     $               ( IPW+WORKSIZ )*CPLXSZ
                   IERR( 1 ) = 1
                END IF
 *
@@ -307,7 +308,7 @@
 *
                IF( IERR( 1 ).GT.0 ) THEN
                   IF( IAM.EQ.0 )
-     $               WRITE( NOUT, FMT = 9997 ) 'MEMORY'
+     $               WRITE( NOUT, FMT = 9997 )'MEMORY'
                   KSKIP = KSKIP + 1
                   GO TO 10
                END IF
@@ -330,26 +331,25 @@
      $                            NDIAG, IPREPAD, IPOSTPAD, PADVAL )
                   CALL PCFILLPAD( ICTXT, NOFFD, 1, MEM( IPE-IPREPAD ),
      $                            NOFFD, IPREPAD, IPOSTPAD, PADVAL )
-                  CALL PCFILLPAD( ICTXT, NQ, 1, MEM( IPT-IPREPAD ),
-     $                            NQ, IPREPAD, IPOSTPAD, PADVAL )
+                  CALL PCFILLPAD( ICTXT, NQ, 1, MEM( IPT-IPREPAD ), NQ,
+     $                            IPREPAD, IPOSTPAD, PADVAL )
                   CALL PCFILLPAD( ICTXT, WORKSIZ-IPOSTPAD, 1,
      $                            MEM( IPW-IPREPAD ), WORKSIZ-IPOSTPAD,
      $                            IPREPAD, IPOSTPAD, PADVAL )
                   ANORM = PCLANHE( 'I', UPLO, N, MEM( IPA ), 1, 1,
-     $                             DESCA, MEM( IPW ) )
+     $                    DESCA, MEM( IPW ) )
                   CALL PCCHEKPAD( ICTXT, 'PCLANHE', NP, NQ,
      $                            MEM( IPA-IPREPAD ), DESCA( LLD_ ),
      $                            IPREPAD, IPOSTPAD, PADVAL )
-                  CALL PCCHEKPAD( ICTXT, 'PCLANHE', WORKSIZ-IPOSTPAD,
-     $                            1, MEM( IPW-IPREPAD ),
-     $                            WORKSIZ-IPOSTPAD, IPREPAD,
-     $                            IPOSTPAD, PADVAL )
+                  CALL PCCHEKPAD( ICTXT, 'PCLANHE', WORKSIZ-IPOSTPAD, 1,
+     $                            MEM( IPW-IPREPAD ), WORKSIZ-IPOSTPAD,
+     $                            IPREPAD, IPOSTPAD, PADVAL )
                   CALL PCFILLPAD( ICTXT, WORKTRD-IPOSTPAD, 1,
      $                            MEM( IPW-IPREPAD ), WORKTRD-IPOSTPAD,
      $                            IPREPAD, IPOSTPAD, PADVAL )
                END IF
 *
-               CALL SLBOOT()
+               CALL SLBOOT
                CALL BLACS_BARRIER( ICTXT, 'All' )
                CALL SLTIMER( 1 )
 *
@@ -377,8 +377,7 @@
                   CALL PCCHEKPAD( ICTXT, 'PCHETRD', NQ, 1,
      $                            MEM( IPT-IPREPAD ), NQ, IPREPAD,
      $                            IPOSTPAD, PADVAL )
-                  CALL PCCHEKPAD( ICTXT, 'PCHETRD',
-     $                            WORKTRD-IPOSTPAD, 1,
+                  CALL PCCHEKPAD( ICTXT, 'PCHETRD', WORKTRD-IPOSTPAD, 1,
      $                            MEM( IPW-IPREPAD ), WORKTRD-IPOSTPAD,
      $                            IPREPAD, IPOSTPAD, PADVAL )
                   CALL PCFILLPAD( ICTXT, WORKSIZ-IPOSTPAD, 1,
@@ -405,27 +404,26 @@
                   CALL PCCHEKPAD( ICTXT, 'PCHETDRV', NOFFD, 1,
      $                            MEM( IPE-IPREPAD ), NOFFD, IPREPAD,
      $                            IPOSTPAD, PADVAL )
-                  CALL PCCHEKPAD( ICTXT, 'PCHETDRV',
-     $                            WORKSIZ-IPOSTPAD, 1,
-     $                            MEM( IPW-IPREPAD ), WORKSIZ-IPOSTPAD,
-     $                            IPREPAD, IPOSTPAD, PADVAL )
+                  CALL PCCHEKPAD( ICTXT, 'PCHETDRV', WORKSIZ-IPOSTPAD,
+     $                            1, MEM( IPW-IPREPAD ),
+     $                            WORKSIZ-IPOSTPAD, IPREPAD, IPOSTPAD,
+     $                            PADVAL )
 *
 *                 Test residual and detect NaN result
 *
-                  IF( FRESID.LE.THRESH .AND. FRESID-FRESID.EQ.0.0E+0
-     $                .AND. IERR( 1 ).EQ.0 ) THEN
+                  IF( FRESID.LE.THRESH .AND. FRESID-FRESID.EQ.
+     $                0.0E+0 .AND. IERR( 1 ).EQ.0 ) THEN
                      KPASS = KPASS + 1
                      PASSED = 'PASSED'
                   ELSE
                      IF( MYROW.EQ.0 .AND. MYCOL.EQ.0 )
-     $                  WRITE( NOUT, FMT = 9986 ) FRESID
+     $                  WRITE( NOUT, FMT = 9986 )FRESID
                      KFAIL = KFAIL + 1
                      PASSED = 'FAILED'
                   END IF
 *
-                  IF( MYROW.EQ.0. AND. MYCOL.EQ.0 .AND. IERR( 1 ).NE.0 )
-     $               WRITE( NOUT, FMT = * )
-     $                     'D or E copies incorrect ...'
+                  IF( MYROW.EQ.0 .AND. MYCOL.EQ.0 .AND. IERR( 1 ).NE.0 )
+     $               WRITE( NOUT, FMT = * )'D or E copies incorrect ...'
                ELSE
 *
 *                 Don't perform the checking, only the timing operation
@@ -442,12 +440,13 @@
 *
 *              Print results
 *
-               IF( MYROW.EQ.0. AND. MYCOL.EQ.0 ) THEN
+               IF( MYROW.EQ.0 .AND. MYCOL.EQ.0 ) THEN
 *
 *                 TRD requires 16/3 N^3 floating point operations
 *
                   NOPS = DBLE( N )
-                  NOPS = ( 16.0D+0 / 3.0D+0 ) * NOPS**3
+*
+                  NOPS = ( 4.0D+0 / 3.0D+0 )*NOPS**3
                   NOPS = NOPS / 1.0D+6
 *
 *                 Print WALL time
@@ -458,9 +457,8 @@
                      TMFLOPS = 0.0D+0
                   END IF
                   IF( WTIME( 1 ).GE.0.0D+0 )
-     $               WRITE( NOUT, FMT = 9993 ) 'WALL', UPLO, N, NB,
-     $                      NPROW, NPCOL, WTIME( 1 ), TMFLOPS, FRESID,
-     $                      PASSED
+     $               WRITE( NOUT, FMT = 9993 )'WALL', UPLO, N, NB,
+     $               NPROW, NPCOL, WTIME( 1 ), TMFLOPS, FRESID, PASSED
 *
 *                 Print CPU time
 *
@@ -470,29 +468,31 @@
                      TMFLOPS = 0.0D+0
                   END IF
                   IF( CTIME( 1 ).GE.0.0D+0 )
-     $               WRITE( NOUT, FMT = 9993 ) 'CPU ', UPLO, N, NB,
-     $                      NPROW, NPCOL, CTIME( 1 ), TMFLOPS, FRESID,
-     $                      PASSED
+     $               WRITE( NOUT, FMT = 9993 )'CPU ', UPLO, N, NB,
+     $               NPROW, NPCOL, CTIME( 1 ), TMFLOPS, FRESID, PASSED
                END IF
    10       CONTINUE
    20    CONTINUE
 *
          CALL BLACS_GRIDEXIT( ICTXT )
    30 CONTINUE
+*
+      CALL PCTTRDTESTER( IAM, NPROCS, CHECK, NOUT, THRESH, NVAL, NMAT,
+     $                   MEM, TOTMEM, KPASS, KFAIL, KSKIP )
 *
 *     Print ending messages and close output file
 *
       IF( IAM.EQ.0 ) THEN
          KTESTS = KPASS + KFAIL + KSKIP
          WRITE( NOUT, FMT = * )
-         WRITE( NOUT, FMT = 9992 ) KTESTS
+         WRITE( NOUT, FMT = 9992 )KTESTS
          IF( CHECK ) THEN
-            WRITE( NOUT, FMT = 9991 ) KPASS
-            WRITE( NOUT, FMT = 9989 ) KFAIL
+            WRITE( NOUT, FMT = 9991 )KPASS
+            WRITE( NOUT, FMT = 9989 )KFAIL
          ELSE
-            WRITE( NOUT, FMT = 9990 ) KPASS
+            WRITE( NOUT, FMT = 9990 )KPASS
          END IF
-         WRITE( NOUT, FMT = 9988 ) KSKIP
+         WRITE( NOUT, FMT = 9988 )KSKIP
          WRITE( NOUT, FMT = * )
          WRITE( NOUT, FMT = * )
          WRITE( NOUT, FMT = 9987 )
@@ -503,18 +503,18 @@
       CALL BLACS_EXIT( 0 )
 *
  9999 FORMAT( 'ILLEGAL ', A6, ': ', A5, ' = ', I3,
-     $        '; It should be at least 1' )
+     $      '; It should be at least 1' )
  9998 FORMAT( 'ILLEGAL GRID: nprow*npcol = ', I4, '. It can be at most',
-     $        I4 )
+     $      I4 )
  9997 FORMAT( 'Bad ', A6, ' parameters: going on to next test case.' )
  9996 FORMAT( 'Unable to perform ', A, ': need TOTMEM of at least',
-     $        I11 )
+     $      I11 )
  9995 FORMAT( 'TIME UPLO      N  NB     P     Q  TRD Time ',
-     $        '     MFLOPS Residual  CHECK' )
+     $      '     MFLOPS Residual  CHECK' )
  9994 FORMAT( '---- ---- ------ --- ----- ----- --------- ',
-     $        '----------- -------- ------' )
- 9993 FORMAT( A4, 1X, A4, 1X, I6, 1X, I3, 1X, I5, 1X, I5, 1X,
-     $        F9.2, 1X, F11.2, 1X, F8.2, 1X, A6 )
+     $      '----------- -------- ------' )
+ 9993 FORMAT( A4, 1X, A4, 1X, I6, 1X, I3, 1X, I5, 1X, I5, 1X, F9.2, 1X,
+     $      F11.2, 1X, F8.2, 1X, A6 )
  9992 FORMAT( 'Finished', I4, ' tests, with the following results:' )
  9991 FORMAT( I5, ' tests completed and passed residual checks.' )
  9990 FORMAT( I5, ' tests completed without checking.' )
