@@ -1,6 +1,6 @@
       PROGRAM PDINVDRIVER
 *
-*  -- ScaLAPACK testing driver (version 1.5) --
+*  -- ScaLAPACK testing driver (version 1.7) --
 *     University of Tennessee, Knoxville, Oak Ridge National Laboratory,
 *     and University of California, Berkeley.
 *     May 1, 1997
@@ -109,7 +109,7 @@
      $                   PDLANSY, PDLANTR
 *     ..
 *     .. Intrinsic Functions ..
-      INTRINSIC          DBLE, MAX
+      INTRINSIC          DBLE, MAX, MOD
 *     ..
 *     .. Data Statements ..
       DATA               KTESTS, KPASS, KFAIL, KSKIP /4*0/
@@ -311,10 +311,21 @@
                      IF( NPROW.EQ.NPCOL ) THEN
                         LIWORK = NQ + DESCA( NB_ )
                      ELSE
-                        LIWORK = MAX( DESCA( NB_ ), DESCA( MB_ ) *
-     $                           ICEIL( ICEIL( DESCA( LLD_ ),
-     $                                  DESCA( MB_ ) ), LCM / NPROW ) )
-     $                                  + NQ
+*
+* change the integer workspace needed for PDGETRI
+*                        LIWORK = MAX( DESCA( NB_ ), DESCA( MB_ ) *
+*     $                           ICEIL( ICEIL( DESCA( LLD_ ),
+*     $                                  DESCA( MB_ ) ), LCM / NPROW ) )
+*     $                                  + NQ
+                         LIWORK = NUMROC( DESCA( M_ ) +
+     $                  DESCA( MB_ ) * NPROW
+     $                  + MOD ( 1 - 1, DESCA( MB_ ) ), DESCA ( NB_ ),
+     $                  MYCOL, DESCA( CSRC_ ), NPCOL ) +
+     $                  MAX ( DESCA( MB_ ) * ICEIL ( ICEIL(
+     $                  NUMROC( DESCA( M_ ) + DESCA( MB_ ) * NPROW,
+     $                  DESCA( MB_ ), MYROW, DESCA( RSRC_ ), NPROW ),
+     $                  DESCA( MB_ ) ), LCM / NPROW ), DESCA( NB_ ) )
+*
                      END IF
                      WORKIINV = ICEIL( LIWORK*INTGSZ, DBLESZ ) +
      $                          IPOSTPAD
